using System;
using System.IO;
using System.Net;
using System.Net.Security;
using System.Security.Cryptography.X509Certificates;
using System.Collections.Generic;
using System.Web.Script.Serialization;

public partial class StandardIntegratedUserVerificationExample : System.Web.UI.Page
{
	protected void Page_Load(object sender, EventArgs e)
	{
		if (!IsPostBack)
		{
            lblIPAddress.Text += Request.UserHostAddress;
		}
		// option: override certificate check so that self-signed certs can be used
		if (ServicePointManager.ServerCertificateValidationCallback == null)
		{
			ServicePointManager.ServerCertificateValidationCallback +=
				delegate(object objSender, X509Certificate certificate, X509Chain chain, SslPolicyErrors errors)
				{
					return true;
				};
		}
	}

    protected void btnSignIn_Click(object sender, EventArgs e)
    {
        string responseText = "";
        try
        {            
            var request = BuildPostRequest("https://e5.onthehub.com/WebStore/Security/AuthenticateUser.ashx");

            using (var response = request.GetResponse())
            {
                var reader = new StreamReader(response.GetResponseStream());
                responseText = reader.ReadToEnd();
            }
        }
        catch (WebException webEx)
        {
            // If the response is not successful then an exception will be thrown and we must can it and
            // read the error message.
            if (webEx.Response == null)
            {
                responseText = "Message: " + webEx.Message;
            }
            else
            {
                responseText = ((HttpWebResponse)webEx.Response).StatusDescription;
            }
        }

        txtResponse.Text = responseText;
        // If the response text is the valid redirect URL then send off the user (if the option is checked)
        if (chkDoRedirect.Checked && (responseText.StartsWith("https://") || responseText.StartsWith("http://")))
        {
            Response.Redirect(responseText, true);
        }
    }

    private WebRequest BuildPostRequest(string url)
    {
        var httpWebRequest = WebRequest.Create(url);
        httpWebRequest.ContentType = "application/json";
        httpWebRequest.Method = "POST";

        var parameterDictionary = BuildParameterDictionary();

        using (var streamWriter = new StreamWriter(httpWebRequest.GetRequestStream()))
        {
            var json = new JavaScriptSerializer().Serialize(parameterDictionary);
            streamWriter.Write(json);            
        }

        return httpWebRequest;
    }

    private Dictionary<string, object> BuildParameterDictionary()
    {
        var dict = new Dictionary<string, object>
        {
            {"username", txtUsername.Text.Trim()},
            {"account", txtAccount.Text.Trim()},
            {"email", txtEmailAddress.Text.Trim()},            
            {"key", txtKey.Text.Trim()}
        };

        var firstName = txtFirstName.Text.Trim();
        if (!String.IsNullOrEmpty(firstName))
        {
            dict.Add("first_name", firstName);
        }
        var lastName = txtLastName.Text.Trim();
        if (!String.IsNullOrEmpty(lastName))
        {
            dict.Add("last_name", lastName);
        }
        var shopperIp = txtShopperIP.Text.Trim();
        if (!String.IsNullOrEmpty(shopperIp))
        {
            dict.Add("shopper_ip", shopperIp);
        }

        // academic statuses - convert to list for json array serialization
        var academicStatuses = txtAcademicStatuses.Text.Trim().Split(',');
        dict.Add("academic_statuses", academicStatuses);
        
        return dict;
    }
}